from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import File, String, Boolean, Int, Directory

Fastq_Dump_Orig_V0_1_0 = CommandToolBuilder(tool="fastq_dump_orig", base_command=["fastq-dump-orig"], inputs=[ToolInput(tag="in_accession", input_type=File(optional=True), prefix="--accession", doc=InputDocumentation(doc="Replaces accession derived from <path> in\nfilename(s) and deflines (only for single\ntable dump)")), ToolInput(tag="in_table", input_type=String(optional=True), prefix="--table", doc=InputDocumentation(doc="Table name within cSRA object, default is\n'SEQUENCE'")), ToolInput(tag="in_split_spot", input_type=Boolean(optional=True), prefix="--split-spot", doc=InputDocumentation(doc="Split spots into individual reads")), ToolInput(tag="in_min_spot_id", input_type=String(optional=True), prefix="--minSpotId", doc=InputDocumentation(doc="Minimum spot id")), ToolInput(tag="in_max_spot_id", input_type=String(optional=True), prefix="--maxSpotId", doc=InputDocumentation(doc="Maximum spot id")), ToolInput(tag="in_spot_groups", input_type=Boolean(optional=True), prefix="--spot-groups", doc=InputDocumentation(doc="<[list]>           Filter by SPOT_GROUP (member): name[,...]")), ToolInput(tag="in_clip", input_type=Boolean(optional=True), prefix="--clip", doc=InputDocumentation(doc="Remove adapter sequences from reads")), ToolInput(tag="in_min_read_len", input_type=Int(optional=True), prefix="--minReadLen", doc=InputDocumentation(doc="Filter by sequence length >= <len>")), ToolInput(tag="in_read_filter", input_type=Boolean(optional=True), prefix="--read-filter", doc=InputDocumentation(doc="<[filter]>      Split into files by READ_FILTER value\noptionally filter by value:\npass|reject|criteria|redacted")), ToolInput(tag="in_qual_filter", input_type=Boolean(optional=True), prefix="--qual-filter", doc=InputDocumentation(doc="Filter used in early 1000 Genomes data: no\nsequences starting or ending with >= 10N")), ToolInput(tag="in_qual_filter_one", input_type=Boolean(optional=True), prefix="--qual-filter-1", doc=InputDocumentation(doc="Filter used in current 1000 Genomes data")), ToolInput(tag="in_aligned", input_type=Boolean(optional=True), prefix="--aligned", doc=InputDocumentation(doc="Dump only aligned sequences")), ToolInput(tag="in_unaligned", input_type=Boolean(optional=True), prefix="--unaligned", doc=InputDocumentation(doc="Dump only unaligned sequences")), ToolInput(tag="in_aligned_region", input_type=Boolean(optional=True), prefix="--aligned-region", doc=InputDocumentation(doc="<name[:from-to]>  Filter by position on genome. Name can\neither be accession.version (ex:\nNC_000001.10) or file specific name (ex:\n'chr1' or '1'). 'from' and 'to' are 1-based\ncoordinates")), ToolInput(tag="in_mate_pair_distance", input_type=String(optional=True), prefix="--matepair-distance", doc=InputDocumentation(doc="Filter by distance between matepairs.\nUse 'unknown' to find matepairs split\nbetween the references. Use from-to to limit\nmatepair distance on the same reference")), ToolInput(tag="in_skip_technical", input_type=Boolean(optional=True), prefix="--skip-technical", doc=InputDocumentation(doc="Dump only biological reads")), ToolInput(tag="in_outdir", input_type=Directory(optional=True), prefix="--outdir", doc=InputDocumentation(doc="Output directory, default is working\ndirectory '.' )")), ToolInput(tag="in_stdout", input_type=Boolean(optional=True), prefix="--stdout", doc=InputDocumentation(doc="Output to stdout, all split data become\njoined into single stream")), ToolInput(tag="in_gzip", input_type=Boolean(optional=True), prefix="--gzip", doc=InputDocumentation(doc="Compress output using gzip: deprecated, not")), ToolInput(tag="in_split_files", input_type=Boolean(optional=True), prefix="--split-files", doc=InputDocumentation(doc="Write reads into separate files. Read\nnumber will be suffixed to the file name.\nNOTE! The `--split-3` option is recommended.\nIn cases where not all spots have the same\nnumber of reads, this option will produce\nfiles that WILL CAUSE ERRORS in most programs\nwhich process split pair fastq files.")), ToolInput(tag="in_split_three", input_type=Boolean(optional=True), prefix="--split-3", doc=InputDocumentation(doc="3-way splitting for mate-pairs. For each\nspot, if there are two biological reads\nsatisfying filter conditions, the first is\nplaced in the `*_1.fastq` file, and the\nsecond is placed in the `*_2.fastq` file. If\nthere is only one biological read\nsatisfying the filter conditions, it is\nplaced in the `*.fastq` file.All other\nreads in the spot are ignored.")), ToolInput(tag="in_spot_group", input_type=Boolean(optional=True), prefix="--spot-group", doc=InputDocumentation(doc="Split into files by SPOT_GROUP (member name)")), ToolInput(tag="in_group_in_dirs", input_type=Boolean(optional=True), prefix="--group-in-dirs", doc=InputDocumentation(doc="Split into subdirectories instead of files")), ToolInput(tag="in_keep_empty_files", input_type=Boolean(optional=True), prefix="--keep-empty-files", doc=InputDocumentation(doc="Do not delete empty files")), ToolInput(tag="in_dump_cs", input_type=Boolean(optional=True), prefix="--dumpcs", doc=InputDocumentation(doc="<[cskey]>            Formats sequence using color space (default\nfor SOLiD),'cskey' may be specified for\ntranslation")), ToolInput(tag="in_dump_base", input_type=Boolean(optional=True), prefix="--dumpbase", doc=InputDocumentation(doc="Formats sequence using base space (default\nfor other than SOLiD).")), ToolInput(tag="in_offset", input_type=Int(optional=True), prefix="--offset", doc=InputDocumentation(doc="Offset to use for quality conversion,\ndefault is 33")), ToolInput(tag="in_fast_a", input_type=Boolean(optional=True), prefix="--fasta", doc=InputDocumentation(doc="<[line width]>           FASTA only, no qualities, optional line\nwrap width (set to zero for no wrapping)")), ToolInput(tag="in_suppress_qual_for_cs_key", input_type=Boolean(optional=True), prefix="--suppress-qual-for-cskey", doc=InputDocumentation(doc="suppress quality-value for cskey")), ToolInput(tag="in_orig_fmt", input_type=Boolean(optional=True), prefix="--origfmt", doc=InputDocumentation(doc="Defline contains only original sequence name")), ToolInput(tag="in_read_ids", input_type=Boolean(optional=True), prefix="--readids", doc=InputDocumentation(doc="Append read id after spot id as\n'accession.spot.readid' on defline")), ToolInput(tag="in_h_elicos", input_type=Boolean(optional=True), prefix="--helicos", doc=InputDocumentation(doc="Helicos style defline")), ToolInput(tag="in_def_line_seq", input_type=String(optional=True), prefix="--defline-seq", doc=InputDocumentation(doc="Defline format specification for sequence.")), ToolInput(tag="in_def_line_qual", input_type=Int(optional=True), prefix="--defline-qual", doc=InputDocumentation(doc="Defline format specification for quality.\n<fmt> is string of characters and/or\nvariables. The variables can be one of: $ac\n- accession, $si spot id, $sn spot\nname, $sg spot group (barcode), $sl spot\nlength in bases, $ri read number, $rn\nread name, $rl read length in bases. '[]'\ncould be used for an optional output: if\nall vars in [] yield empty values whole\ngroup is not printed. Empty value is empty\nstring or for numeric variables. Ex:\n@$sn[_$rn]/$ri '_$rn' is omitted if name\nis empty")), ToolInput(tag="in_ngc", input_type=File(optional=True), prefix="--ngc", doc=InputDocumentation(doc="<path> to ngc file")), ToolInput(tag="in_disable_multithreading", input_type=Boolean(optional=True), prefix="--disable-multithreading", doc=InputDocumentation(doc="disable multithreading")), ToolInput(tag="in_log_level", input_type=Int(optional=True), prefix="--log-level", doc=InputDocumentation(doc="Logging level as number or enum string One\nof (fatal|sys|int|err|warn|info) or (0-5)\nCurrent/default is warn")), ToolInput(tag="in_verbose", input_type=Boolean(optional=True), prefix="--verbose", doc=InputDocumentation(doc="Increase the verbosity level of the program\nUse multiple times for more verbosity")), ToolInput(tag="in_ncbi_error_report", input_type=Boolean(optional=True), prefix="--ncbi_error_report", doc=InputDocumentation(doc="Control program execution environment\nreport generation (if implemented). One of\n(never|error|always). Default is error")), ToolInput(tag="in_legacy_report", input_type=Boolean(optional=True), prefix="--legacy-report", doc=InputDocumentation(doc="use legacy style 'Written spots' for tool")), ToolInput(tag="in_recommended", input_type=String(), position=0, doc=InputDocumentation(doc="--bzip2                          Compress output using bzip2: deprecated, "))], outputs=[ToolOutput(tag="out_outdir", output_type=Directory(optional=True), selector=InputSelector(input_to_select="in_outdir", type_hint=File()), doc=OutputDocumentation(doc="Output directory, default is working\ndirectory '.' )"))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Fastq_Dump_Orig_V0_1_0().translate("wdl", allow_empty_container=True)

